@@ -1,14 +1,12 @@
 """
-Type annotations for codebuild service type definitions.
-
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/type_defs.html)
+Main interface for codebuild service type definitions.
 
 Usage::
 
     ```python
-    from mypy_boto3_codebuild.type_defs import BatchDeleteBuildsOutputTypeDef
+    from mypy_boto3_codebuild.type_defs import BatchRestrictionsTypeDef
 
-    data: BatchDeleteBuildsOutputTypeDef = {...}
+    data: BatchRestrictionsTypeDef = {...}
     ```
 """
 import sys
@@ -26,8 +24,10 @@ from mypy_boto3_codebuild.literals import (
     CacheMode,
     CacheType,
     ComputeType,
+    CredentialProviderType,
     EnvironmentType,
     EnvironmentVariableType,
+    FileSystemType,
     ImagePullCredentialsType,
     LanguageType,
     LogsConfigStatusType,
@@ -38,16 +38,13 @@ from mypy_boto3_codebuild.literals import (
     ReportStatusType,
     ReportType,
     ServerType,
+    SourceAuthType,
     SourceType,
     StatusType,
     WebhookBuildType,
     WebhookFilterType,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -55,15 +52,8 @@ else:
 
 
 __all__ = (
-    "BatchDeleteBuildsOutputTypeDef",
-    "BatchGetBuildBatchesOutputTypeDef",
-    "BatchGetBuildsOutputTypeDef",
-    "BatchGetProjectsOutputTypeDef",
-    "BatchGetReportGroupsOutputTypeDef",
-    "BatchGetReportsOutputTypeDef",
     "BatchRestrictionsTypeDef",
     "BuildArtifactsTypeDef",
-    "BuildBatchFilterTypeDef",
     "BuildBatchPhaseTypeDef",
     "BuildBatchTypeDef",
     "BuildGroupTypeDef",
@@ -75,22 +65,60 @@ __all__ = (
     "CloudWatchLogsConfigTypeDef",
     "CodeCoverageReportSummaryTypeDef",
     "CodeCoverageTypeDef",
-    "CreateProjectOutputTypeDef",
-    "CreateReportGroupOutputTypeDef",
-    "CreateWebhookOutputTypeDef",
     "DebugSessionTypeDef",
-    "DeleteBuildBatchOutputTypeDef",
-    "DeleteSourceCredentialsOutputTypeDef",
-    "DescribeCodeCoveragesOutputTypeDef",
-    "DescribeTestCasesOutputTypeDef",
     "EnvironmentImageTypeDef",
     "EnvironmentLanguageTypeDef",
     "EnvironmentPlatformTypeDef",
     "EnvironmentVariableTypeDef",
     "ExportedEnvironmentVariableTypeDef",
+    "GitSubmodulesConfigTypeDef",
+    "LogsConfigTypeDef",
+    "LogsLocationTypeDef",
+    "NetworkInterfaceTypeDef",
+    "PhaseContextTypeDef",
+    "ProjectArtifactsTypeDef",
+    "ProjectBadgeTypeDef",
+    "ProjectBuildBatchConfigTypeDef",
+    "ProjectCacheTypeDef",
+    "ProjectEnvironmentTypeDef",
+    "ProjectFileSystemLocationTypeDef",
+    "ProjectSourceTypeDef",
+    "ProjectSourceVersionTypeDef",
+    "ProjectTypeDef",
+    "RegistryCredentialTypeDef",
+    "ReportExportConfigTypeDef",
+    "ReportGroupTrendStatsTypeDef",
+    "ReportGroupTypeDef",
+    "ReportTypeDef",
+    "ReportWithRawDataTypeDef",
+    "ResolvedArtifactTypeDef",
+    "ResponseMetadata",
+    "S3LogsConfigTypeDef",
+    "S3ReportExportConfigTypeDef",
+    "SourceAuthTypeDef",
+    "SourceCredentialsInfoTypeDef",
+    "TagTypeDef",
+    "TestCaseTypeDef",
+    "TestReportSummaryTypeDef",
+    "VpcConfigTypeDef",
+    "WebhookFilterTypeDef",
+    "WebhookTypeDef",
+    "BatchDeleteBuildsOutputTypeDef",
+    "BatchGetBuildBatchesOutputTypeDef",
+    "BatchGetBuildsOutputTypeDef",
+    "BatchGetProjectsOutputTypeDef",
+    "BatchGetReportGroupsOutputTypeDef",
+    "BatchGetReportsOutputTypeDef",
+    "BuildBatchFilterTypeDef",
+    "CreateProjectOutputTypeDef",
+    "CreateReportGroupOutputTypeDef",
+    "CreateWebhookOutputTypeDef",
+    "DeleteBuildBatchOutputTypeDef",
+    "DeleteSourceCredentialsOutputTypeDef",
+    "DescribeCodeCoveragesOutputTypeDef",
+    "DescribeTestCasesOutputTypeDef",
     "GetReportGroupTrendOutputTypeDef",
     "GetResourcePolicyOutputTypeDef",
-    "GitSubmodulesConfigTypeDef",
     "ImportSourceCredentialsOutputTypeDef",
     "ListBuildBatchesForProjectOutputTypeDef",
     "ListBuildBatchesOutputTypeDef",
@@ -104,116 +132,53 @@ __all__ = (
     "ListSharedProjectsOutputTypeDef",
     "ListSharedReportGroupsOutputTypeDef",
     "ListSourceCredentialsOutputTypeDef",
-    "LogsConfigTypeDef",
-    "LogsLocationTypeDef",
-    "NetworkInterfaceTypeDef",
     "PaginatorConfigTypeDef",
-    "PhaseContextTypeDef",
-    "ProjectArtifactsTypeDef",
-    "ProjectBadgeTypeDef",
-    "ProjectBuildBatchConfigTypeDef",
-    "ProjectCacheTypeDef",
-    "ProjectEnvironmentTypeDef",
-    "ProjectFileSystemLocationTypeDef",
-    "ProjectSourceTypeDef",
-    "ProjectSourceVersionTypeDef",
-    "ProjectTypeDef",
     "PutResourcePolicyOutputTypeDef",
-    "RegistryCredentialTypeDef",
-    "ReportExportConfigTypeDef",
     "ReportFilterTypeDef",
-    "ReportGroupTrendStatsTypeDef",
-    "ReportGroupTypeDef",
-    "ReportTypeDef",
-    "ReportWithRawDataTypeDef",
-    "ResolvedArtifactTypeDef",
-    "ResponseMetadata",
     "RetryBuildBatchOutputTypeDef",
     "RetryBuildOutputTypeDef",
-    "S3LogsConfigTypeDef",
-    "S3ReportExportConfigTypeDef",
-    "SourceAuthTypeDef",
-    "SourceCredentialsInfoTypeDef",
     "StartBuildBatchOutputTypeDef",
     "StartBuildOutputTypeDef",
     "StopBuildBatchOutputTypeDef",
     "StopBuildOutputTypeDef",
-    "TagTypeDef",
     "TestCaseFilterTypeDef",
-    "TestCaseTypeDef",
-    "TestReportSummaryTypeDef",
     "UpdateProjectOutputTypeDef",
     "UpdateReportGroupOutputTypeDef",
     "UpdateWebhookOutputTypeDef",
-    "VpcConfigTypeDef",
-    "WebhookFilterTypeDef",
-    "WebhookTypeDef",
 )
 
+BatchRestrictionsTypeDef = TypedDict(
+    "BatchRestrictionsTypeDef",
+    {"maximumBuildsAllowed": int, "computeTypesAllowed": List[str]},
+    total=False,
+)
 
-class BatchDeleteBuildsOutputTypeDef(TypedDict):
-    buildsDeleted: List[str]
-    buildsNotDeleted: List["BuildNotDeletedTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class BatchGetBuildBatchesOutputTypeDef(TypedDict):
-    buildBatches: List["BuildBatchTypeDef"]
-    buildBatchesNotFound: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class BatchGetBuildsOutputTypeDef(TypedDict):
-    builds: List["BuildTypeDef"]
-    buildsNotFound: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class BatchGetProjectsOutputTypeDef(TypedDict):
-    projects: List["ProjectTypeDef"]
-    projectsNotFound: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class BatchGetReportGroupsOutputTypeDef(TypedDict):
-    reportGroups: List["ReportGroupTypeDef"]
-    reportGroupsNotFound: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class BatchGetReportsOutputTypeDef(TypedDict):
-    reports: List["ReportTypeDef"]
-    reportsNotFound: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class BatchRestrictionsTypeDef(TypedDict, total=False):
-    maximumBuildsAllowed: int
-    computeTypesAllowed: List[str]
-
-
-class BuildArtifactsTypeDef(TypedDict, total=False):
-    location: str
-    sha256sum: str
-    md5sum: str
-    overrideArtifactName: bool
-    encryptionDisabled: bool
-    artifactIdentifier: str
-    bucketOwnerAccess: BucketOwnerAccess
-
-
-class BuildBatchFilterTypeDef(TypedDict, total=False):
-    status: StatusType
-
-
-class BuildBatchPhaseTypeDef(TypedDict, total=False):
-    phaseType: BuildBatchPhaseType
-    phaseStatus: StatusType
-    startTime: datetime
-    endTime: datetime
-    durationInSeconds: int
-    contexts: List["PhaseContextTypeDef"]
+BuildArtifactsTypeDef = TypedDict(
+    "BuildArtifactsTypeDef",
+    {
+        "location": str,
+        "sha256sum": str,
+        "md5sum": str,
+        "overrideArtifactName": bool,
+        "encryptionDisabled": bool,
+        "artifactIdentifier": str,
+        "bucketOwnerAccess": BucketOwnerAccess,
+    },
+    total=False,
+)
 
+BuildBatchPhaseTypeDef = TypedDict(
+    "BuildBatchPhaseTypeDef",
+    {
+        "phaseType": BuildBatchPhaseType,
+        "phaseStatus": StatusType,
+        "startTime": datetime,
+        "endTime": datetime,
+        "durationInSeconds": int,
+        "contexts": List["PhaseContextTypeDef"],
+    },
+    total=False,
+)
 
 BuildBatchTypeDef = TypedDict(
     "BuildBatchTypeDef",
@@ -252,41 +217,50 @@ BuildBatchTypeDef = TypedDict(
     total=False,
 )
 
-
-class BuildGroupTypeDef(TypedDict, total=False):
-    identifier: str
-    dependsOn: List[str]
-    ignoreFailure: bool
-    currentBuildSummary: "BuildSummaryTypeDef"
-    priorBuildSummaryList: List["BuildSummaryTypeDef"]
-
+BuildGroupTypeDef = TypedDict(
+    "BuildGroupTypeDef",
+    {
+        "identifier": str,
+        "dependsOn": List[str],
+        "ignoreFailure": bool,
+        "currentBuildSummary": "BuildSummaryTypeDef",
+        "priorBuildSummaryList": List["BuildSummaryTypeDef"],
+    },
+    total=False,
+)
 
 BuildNotDeletedTypeDef = TypedDict(
     "BuildNotDeletedTypeDef", {"id": str, "statusCode": str}, total=False
 )
 
+BuildPhaseTypeDef = TypedDict(
+    "BuildPhaseTypeDef",
+    {
+        "phaseType": BuildPhaseType,
+        "phaseStatus": StatusType,
+        "startTime": datetime,
+        "endTime": datetime,
+        "durationInSeconds": int,
+        "contexts": List["PhaseContextTypeDef"],
+    },
+    total=False,
+)
 
-class BuildPhaseTypeDef(TypedDict, total=False):
-    phaseType: BuildPhaseType
-    phaseStatus: StatusType
-    startTime: datetime
-    endTime: datetime
-    durationInSeconds: int
-    contexts: List["PhaseContextTypeDef"]
-
-
-class BuildStatusConfigTypeDef(TypedDict, total=False):
-    context: str
-    targetUrl: str
-
-
-class BuildSummaryTypeDef(TypedDict, total=False):
-    arn: str
-    requestedOn: datetime
-    buildStatus: StatusType
-    primaryArtifact: "ResolvedArtifactTypeDef"
-    secondaryArtifacts: List["ResolvedArtifactTypeDef"]
+BuildStatusConfigTypeDef = TypedDict(
+    "BuildStatusConfigTypeDef", {"context": str, "targetUrl": str}, total=False
+)
 
+BuildSummaryTypeDef = TypedDict(
+    "BuildSummaryTypeDef",
+    {
+        "arn": str,
+        "requestedOn": datetime,
+        "buildStatus": StatusType,
+        "primaryArtifact": "ResolvedArtifactTypeDef",
+        "secondaryArtifacts": List["ResolvedArtifactTypeDef"],
+    },
+    total=False,
+)
 
 BuildTypeDef = TypedDict(
     "BuildTypeDef",
@@ -327,24 +301,32 @@ BuildTypeDef = TypedDict(
     total=False,
 )
 
-
-class _RequiredCloudWatchLogsConfigTypeDef(TypedDict):
-    status: LogsConfigStatusType
+_RequiredCloudWatchLogsConfigTypeDef = TypedDict(
+    "_RequiredCloudWatchLogsConfigTypeDef", {"status": LogsConfigStatusType}
+)
+_OptionalCloudWatchLogsConfigTypeDef = TypedDict(
+    "_OptionalCloudWatchLogsConfigTypeDef", {"groupName": str, "streamName": str}, total=False
+)
 
 
-class CloudWatchLogsConfigTypeDef(_RequiredCloudWatchLogsConfigTypeDef, total=False):
-    groupName: str
-    streamName: str
+class CloudWatchLogsConfigTypeDef(
+    _RequiredCloudWatchLogsConfigTypeDef, _OptionalCloudWatchLogsConfigTypeDef
+):
+    pass
 
 
-class CodeCoverageReportSummaryTypeDef(TypedDict, total=False):
-    lineCoveragePercentage: float
-    linesCovered: int
-    linesMissed: int
-    branchCoveragePercentage: float
-    branchesCovered: int
-    branchesMissed: int
-
+CodeCoverageReportSummaryTypeDef = TypedDict(
+    "CodeCoverageReportSummaryTypeDef",
+    {
+        "lineCoveragePercentage": float,
+        "linesCovered": int,
+        "linesMissed": int,
+        "branchCoveragePercentage": float,
+        "branchesCovered": int,
+        "branchesMissed": int,
+    },
+    total=False,
+)
 
 CodeCoverageTypeDef = TypedDict(
     "CodeCoverageTypeDef",
@@ -363,66 +345,25 @@ CodeCoverageTypeDef = TypedDict(
     total=False,
 )
 
+DebugSessionTypeDef = TypedDict(
+    "DebugSessionTypeDef", {"sessionEnabled": bool, "sessionTarget": str}, total=False
+)
 
-class CreateProjectOutputTypeDef(TypedDict):
-    project: "ProjectTypeDef"
-    ResponseMetadata: "ResponseMetadata"
+EnvironmentImageTypeDef = TypedDict(
+    "EnvironmentImageTypeDef", {"name": str, "description": str, "versions": List[str]}, total=False
+)
 
+EnvironmentLanguageTypeDef = TypedDict(
+    "EnvironmentLanguageTypeDef",
+    {"language": LanguageType, "images": List["EnvironmentImageTypeDef"]},
+    total=False,
+)
 
-class CreateReportGroupOutputTypeDef(TypedDict):
-    reportGroup: "ReportGroupTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class CreateWebhookOutputTypeDef(TypedDict):
-    webhook: "WebhookTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class DebugSessionTypeDef(TypedDict, total=False):
-    sessionEnabled: bool
-    sessionTarget: str
-
-
-class DeleteBuildBatchOutputTypeDef(TypedDict):
-    statusCode: str
-    buildsDeleted: List[str]
-    buildsNotDeleted: List["BuildNotDeletedTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class DeleteSourceCredentialsOutputTypeDef(TypedDict):
-    arn: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class DescribeCodeCoveragesOutputTypeDef(TypedDict):
-    nextToken: str
-    codeCoverages: List["CodeCoverageTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class DescribeTestCasesOutputTypeDef(TypedDict):
-    nextToken: str
-    testCases: List["TestCaseTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class EnvironmentImageTypeDef(TypedDict, total=False):
-    name: str
-    description: str
-    versions: List[str]
-
-
-class EnvironmentLanguageTypeDef(TypedDict, total=False):
-    language: LanguageType
-    images: List["EnvironmentImageTypeDef"]
-
-
-class EnvironmentPlatformTypeDef(TypedDict, total=False):
-    platform: PlatformType
-    languages: List["EnvironmentLanguageTypeDef"]
-
+EnvironmentPlatformTypeDef = TypedDict(
+    "EnvironmentPlatformTypeDef",
+    {"platform": PlatformType, "languages": List["EnvironmentLanguageTypeDef"]},
+    total=False,
+)
 
 _RequiredEnvironmentVariableTypeDef = TypedDict(
     "_RequiredEnvironmentVariableTypeDef", {"name": str, "value": str}
@@ -438,132 +379,40 @@ class EnvironmentVariableTypeDef(
     pass
 
 
-class ExportedEnvironmentVariableTypeDef(TypedDict, total=False):
-    name: str
-    value: str
+ExportedEnvironmentVariableTypeDef = TypedDict(
+    "ExportedEnvironmentVariableTypeDef", {"name": str, "value": str}, total=False
+)
 
+GitSubmodulesConfigTypeDef = TypedDict("GitSubmodulesConfigTypeDef", {"fetchSubmodules": bool})
 
-class GetReportGroupTrendOutputTypeDef(TypedDict):
-    stats: "ReportGroupTrendStatsTypeDef"
-    rawData: List["ReportWithRawDataTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
+LogsConfigTypeDef = TypedDict(
+    "LogsConfigTypeDef",
+    {"cloudWatchLogs": "CloudWatchLogsConfigTypeDef", "s3Logs": "S3LogsConfigTypeDef"},
+    total=False,
+)
 
+LogsLocationTypeDef = TypedDict(
+    "LogsLocationTypeDef",
+    {
+        "groupName": str,
+        "streamName": str,
+        "deepLink": str,
+        "s3DeepLink": str,
+        "cloudWatchLogsArn": str,
+        "s3LogsArn": str,
+        "cloudWatchLogs": "CloudWatchLogsConfigTypeDef",
+        "s3Logs": "S3LogsConfigTypeDef",
+    },
+    total=False,
+)
 
-class GetResourcePolicyOutputTypeDef(TypedDict):
-    policy: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class GitSubmodulesConfigTypeDef(TypedDict):
-    fetchSubmodules: bool
-
-
-class ImportSourceCredentialsOutputTypeDef(TypedDict):
-    arn: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListBuildBatchesForProjectOutputTypeDef(TypedDict):
-    ids: List[str]
-    nextToken: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListBuildBatchesOutputTypeDef(TypedDict):
-    ids: List[str]
-    nextToken: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListBuildsForProjectOutputTypeDef(TypedDict):
-    ids: List[str]
-    nextToken: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListBuildsOutputTypeDef(TypedDict):
-    ids: List[str]
-    nextToken: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListCuratedEnvironmentImagesOutputTypeDef(TypedDict):
-    platforms: List["EnvironmentPlatformTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListProjectsOutputTypeDef(TypedDict):
-    nextToken: str
-    projects: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListReportGroupsOutputTypeDef(TypedDict):
-    nextToken: str
-    reportGroups: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListReportsForReportGroupOutputTypeDef(TypedDict):
-    nextToken: str
-    reports: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListReportsOutputTypeDef(TypedDict):
-    nextToken: str
-    reports: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListSharedProjectsOutputTypeDef(TypedDict):
-    nextToken: str
-    projects: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListSharedReportGroupsOutputTypeDef(TypedDict):
-    nextToken: str
-    reportGroups: List[str]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class ListSourceCredentialsOutputTypeDef(TypedDict):
-    sourceCredentialsInfos: List["SourceCredentialsInfoTypeDef"]
-    ResponseMetadata: "ResponseMetadata"
-
-
-class LogsConfigTypeDef(TypedDict, total=False):
-    cloudWatchLogs: "CloudWatchLogsConfigTypeDef"
-    s3Logs: "S3LogsConfigTypeDef"
-
-
-class LogsLocationTypeDef(TypedDict, total=False):
-    groupName: str
-    streamName: str
-    deepLink: str
-    s3DeepLink: str
-    cloudWatchLogsArn: str
-    s3LogsArn: str
-    cloudWatchLogs: "CloudWatchLogsConfigTypeDef"
-    s3Logs: "S3LogsConfigTypeDef"
-
-
-class NetworkInterfaceTypeDef(TypedDict, total=False):
-    subnetId: str
-    networkInterfaceId: str
-
-
-class PaginatorConfigTypeDef(TypedDict, total=False):
-    MaxItems: int
-    PageSize: int
-    StartingToken: str
-
-
-class PhaseContextTypeDef(TypedDict, total=False):
-    statusCode: str
-    message: str
+NetworkInterfaceTypeDef = TypedDict(
+    "NetworkInterfaceTypeDef", {"subnetId": str, "networkInterfaceId": str}, total=False
+)
 
+PhaseContextTypeDef = TypedDict(
+    "PhaseContextTypeDef", {"statusCode": str, "message": str}, total=False
+)
 
 _RequiredProjectArtifactsTypeDef = TypedDict(
     "_RequiredProjectArtifactsTypeDef", {"type": ArtifactsType}
@@ -589,17 +438,20 @@ class ProjectArtifactsTypeDef(_RequiredProjectArtifactsTypeDef, _OptionalProject
     pass
 
 
-class ProjectBadgeTypeDef(TypedDict, total=False):
-    badgeEnabled: bool
-    badgeRequestUrl: str
-
-
-class ProjectBuildBatchConfigTypeDef(TypedDict, total=False):
-    serviceRole: str
-    combineArtifacts: bool
-    restrictions: "BatchRestrictionsTypeDef"
-    timeoutInMins: int
+ProjectBadgeTypeDef = TypedDict(
+    "ProjectBadgeTypeDef", {"badgeEnabled": bool, "badgeRequestUrl": str}, total=False
+)
 
+ProjectBuildBatchConfigTypeDef = TypedDict(
+    "ProjectBuildBatchConfigTypeDef",
+    {
+        "serviceRole": str,
+        "combineArtifacts": bool,
+        "restrictions": "BatchRestrictionsTypeDef",
+        "timeoutInMins": int,
+    },
+    total=False,
+)
 
 _RequiredProjectCacheTypeDef = TypedDict("_RequiredProjectCacheTypeDef", {"type": CacheType})
 _OptionalProjectCacheTypeDef = TypedDict(
@@ -637,7 +489,7 @@ class ProjectEnvironmentTypeDef(
 ProjectFileSystemLocationTypeDef = TypedDict(
     "ProjectFileSystemLocationTypeDef",
     {
-        "type": Literal["EFS"],
+        "type": FileSystemType,
         "location": str,
         "mountPoint": str,
         "identifier": str,
@@ -668,57 +520,51 @@ class ProjectSourceTypeDef(_RequiredProjectSourceTypeDef, _OptionalProjectSource
     pass
 
 
-class ProjectSourceVersionTypeDef(TypedDict):
-    sourceIdentifier: str
-    sourceVersion: str
+ProjectSourceVersionTypeDef = TypedDict(
+    "ProjectSourceVersionTypeDef", {"sourceIdentifier": str, "sourceVersion": str}
+)
 
+ProjectTypeDef = TypedDict(
+    "ProjectTypeDef",
+    {
+        "name": str,
+        "arn": str,
+        "description": str,
+        "source": "ProjectSourceTypeDef",
+        "secondarySources": List["ProjectSourceTypeDef"],
+        "sourceVersion": str,
+        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "artifacts": "ProjectArtifactsTypeDef",
+        "secondaryArtifacts": List["ProjectArtifactsTypeDef"],
+        "cache": "ProjectCacheTypeDef",
+        "environment": "ProjectEnvironmentTypeDef",
+        "serviceRole": str,
+        "timeoutInMinutes": int,
+        "queuedTimeoutInMinutes": int,
+        "encryptionKey": str,
+        "tags": List["TagTypeDef"],
+        "created": datetime,
+        "lastModified": datetime,
+        "webhook": "WebhookTypeDef",
+        "vpcConfig": "VpcConfigTypeDef",
+        "badge": "ProjectBadgeTypeDef",
+        "logsConfig": "LogsConfigTypeDef",
+        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
+        "concurrentBuildLimit": int,
+    },
+    total=False,
+)
 
-class ProjectTypeDef(TypedDict, total=False):
-    name: str
-    arn: str
-    description: str
-    source: "ProjectSourceTypeDef"
-    secondarySources: List["ProjectSourceTypeDef"]
-    sourceVersion: str
-    secondarySourceVersions: List["ProjectSourceVersionTypeDef"]
-    artifacts: "ProjectArtifactsTypeDef"
-    secondaryArtifacts: List["ProjectArtifactsTypeDef"]
-    cache: "ProjectCacheTypeDef"
-    environment: "ProjectEnvironmentTypeDef"
-    serviceRole: str
-    timeoutInMinutes: int
-    queuedTimeoutInMinutes: int
-    encryptionKey: str
-    tags: List["TagTypeDef"]
-    created: datetime
-    lastModified: datetime
-    webhook: "WebhookTypeDef"
-    vpcConfig: "VpcConfigTypeDef"
-    badge: "ProjectBadgeTypeDef"
-    logsConfig: "LogsConfigTypeDef"
-    fileSystemLocations: List["ProjectFileSystemLocationTypeDef"]
-    buildBatchConfig: "ProjectBuildBatchConfigTypeDef"
-    concurrentBuildLimit: int
-
-
-class PutResourcePolicyOutputTypeDef(TypedDict):
-    resourceArn: str
-    ResponseMetadata: "ResponseMetadata"
-
-
-class RegistryCredentialTypeDef(TypedDict):
-    credential: str
-    credentialProvider: Literal["SECRETS_MANAGER"]
-
-
-class ReportExportConfigTypeDef(TypedDict, total=False):
-    exportConfigType: ReportExportConfigType
-    s3Destination: "S3ReportExportConfigTypeDef"
-
-
-class ReportFilterTypeDef(TypedDict, total=False):
-    status: ReportStatusType
+RegistryCredentialTypeDef = TypedDict(
+    "RegistryCredentialTypeDef", {"credential": str, "credentialProvider": CredentialProviderType}
+)
 
+ReportExportConfigTypeDef = TypedDict(
+    "ReportExportConfigTypeDef",
+    {"exportConfigType": ReportExportConfigType, "s3Destination": "S3ReportExportConfigTypeDef"},
+    total=False,
+)
 
 ReportGroupTrendStatsTypeDef = TypedDict(
     "ReportGroupTrendStatsTypeDef", {"average": str, "max": str, "min": str}, total=False
@@ -758,11 +604,9 @@ ReportTypeDef = TypedDict(
     total=False,
 )
 
-
-class ReportWithRawDataTypeDef(TypedDict, total=False):
-    reportArn: str
-    data: str
-
+ReportWithRawDataTypeDef = TypedDict(
+    "ReportWithRawDataTypeDef", {"reportArn": str, "data": str}, total=False
+)
 
 ResolvedArtifactTypeDef = TypedDict(
     "ResolvedArtifactTypeDef",
@@ -770,45 +614,45 @@ ResolvedArtifactTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
 
-class ResponseMetadata(TypedDict):
-    RequestId: str
-    HostId: str
-    HTTPStatusCode: int
-    HTTPHeaders: Dict[str, Any]
-    RetryAttempts: int
+_RequiredS3LogsConfigTypeDef = TypedDict(
+    "_RequiredS3LogsConfigTypeDef", {"status": LogsConfigStatusType}
+)
+_OptionalS3LogsConfigTypeDef = TypedDict(
+    "_OptionalS3LogsConfigTypeDef",
+    {"location": str, "encryptionDisabled": bool, "bucketOwnerAccess": BucketOwnerAccess},
+    total=False,
+)
 
 
-class RetryBuildBatchOutputTypeDef(TypedDict):
-    buildBatch: "BuildBatchTypeDef"
-    ResponseMetadata: "ResponseMetadata"
+class S3LogsConfigTypeDef(_RequiredS3LogsConfigTypeDef, _OptionalS3LogsConfigTypeDef):
+    pass
 
 
-class RetryBuildOutputTypeDef(TypedDict):
-    build: "BuildTypeDef"
-    ResponseMetadata: "ResponseMetadata"
+S3ReportExportConfigTypeDef = TypedDict(
+    "S3ReportExportConfigTypeDef",
+    {
+        "bucket": str,
+        "bucketOwner": str,
+        "path": str,
+        "packaging": ReportPackagingType,
+        "encryptionKey": str,
+        "encryptionDisabled": bool,
+    },
+    total=False,
+)
 
-
-class _RequiredS3LogsConfigTypeDef(TypedDict):
-    status: LogsConfigStatusType
-
-
-class S3LogsConfigTypeDef(_RequiredS3LogsConfigTypeDef, total=False):
-    location: str
-    encryptionDisabled: bool
-    bucketOwnerAccess: BucketOwnerAccess
-
-
-class S3ReportExportConfigTypeDef(TypedDict, total=False):
-    bucket: str
-    bucketOwner: str
-    path: str
-    packaging: ReportPackagingType
-    encryptionKey: str
-    encryptionDisabled: bool
-
-
-_RequiredSourceAuthTypeDef = TypedDict("_RequiredSourceAuthTypeDef", {"type": Literal["OAUTH"]})
+_RequiredSourceAuthTypeDef = TypedDict("_RequiredSourceAuthTypeDef", {"type": SourceAuthType})
 _OptionalSourceAuthTypeDef = TypedDict("_OptionalSourceAuthTypeDef", {"resource": str}, total=False)
 
 
@@ -816,79 +660,39 @@ class SourceAuthTypeDef(_RequiredSourceAuthTypeDef, _OptionalSourceAuthTypeDef):
     pass
 
 
-class SourceCredentialsInfoTypeDef(TypedDict, total=False):
-    arn: str
-    serverType: ServerType
-    authType: AuthType
+SourceCredentialsInfoTypeDef = TypedDict(
+    "SourceCredentialsInfoTypeDef",
+    {"arn": str, "serverType": ServerType, "authType": AuthType},
+    total=False,
+)
 
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str}, total=False)
 
-class StartBuildBatchOutputTypeDef(TypedDict):
-    buildBatch: "BuildBatchTypeDef"
-    ResponseMetadata: "ResponseMetadata"
+TestCaseTypeDef = TypedDict(
+    "TestCaseTypeDef",
+    {
+        "reportArn": str,
+        "testRawDataPath": str,
+        "prefix": str,
+        "name": str,
+        "status": str,
+        "durationInNanoSeconds": int,
+        "message": str,
+        "expired": datetime,
+    },
+    total=False,
+)
 
+TestReportSummaryTypeDef = TypedDict(
+    "TestReportSummaryTypeDef",
+    {"total": int, "statusCounts": Dict[str, int], "durationInNanoSeconds": int},
+)
 
-class StartBuildOutputTypeDef(TypedDict):
-    build: "BuildTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class StopBuildBatchOutputTypeDef(TypedDict):
-    buildBatch: "BuildBatchTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class StopBuildOutputTypeDef(TypedDict):
-    build: "BuildTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class TagTypeDef(TypedDict, total=False):
-    key: str
-    value: str
-
-
-class TestCaseFilterTypeDef(TypedDict, total=False):
-    status: str
-    keyword: str
-
-
-class TestCaseTypeDef(TypedDict, total=False):
-    reportArn: str
-    testRawDataPath: str
-    prefix: str
-    name: str
-    status: str
-    durationInNanoSeconds: int
-    message: str
-    expired: datetime
-
-
-class TestReportSummaryTypeDef(TypedDict):
-    total: int
-    statusCounts: Dict[str, int]
-    durationInNanoSeconds: int
-
-
-class UpdateProjectOutputTypeDef(TypedDict):
-    project: "ProjectTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class UpdateReportGroupOutputTypeDef(TypedDict):
-    reportGroup: "ReportGroupTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class UpdateWebhookOutputTypeDef(TypedDict):
-    webhook: "WebhookTypeDef"
-    ResponseMetadata: "ResponseMetadata"
-
-
-class VpcConfigTypeDef(TypedDict, total=False):
-    vpcId: str
-    subnets: List[str]
-    securityGroupIds: List[str]
-
+VpcConfigTypeDef = TypedDict(
+    "VpcConfigTypeDef",
+    {"vpcId": str, "subnets": List[str], "securityGroupIds": List[str]},
+    total=False,
+)
 
 _RequiredWebhookFilterTypeDef = TypedDict(
     "_RequiredWebhookFilterTypeDef", {"type": WebhookFilterType, "pattern": str}
@@ -902,11 +706,300 @@ class WebhookFilterTypeDef(_RequiredWebhookFilterTypeDef, _OptionalWebhookFilter
     pass
 
 
-class WebhookTypeDef(TypedDict, total=False):
-    url: str
-    payloadUrl: str
-    secret: str
-    branchFilter: str
-    filterGroups: List[List["WebhookFilterTypeDef"]]
-    buildType: WebhookBuildType
-    lastModifiedSecret: datetime
+WebhookTypeDef = TypedDict(
+    "WebhookTypeDef",
+    {
+        "url": str,
+        "payloadUrl": str,
+        "secret": str,
+        "branchFilter": str,
+        "filterGroups": List[List["WebhookFilterTypeDef"]],
+        "buildType": WebhookBuildType,
+        "lastModifiedSecret": datetime,
+    },
+    total=False,
+)
+
+BatchDeleteBuildsOutputTypeDef = TypedDict(
+    "BatchDeleteBuildsOutputTypeDef",
+    {
+        "buildsDeleted": List[str],
+        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+BatchGetBuildBatchesOutputTypeDef = TypedDict(
+    "BatchGetBuildBatchesOutputTypeDef",
+    {
+        "buildBatches": List["BuildBatchTypeDef"],
+        "buildBatchesNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+BatchGetBuildsOutputTypeDef = TypedDict(
+    "BatchGetBuildsOutputTypeDef",
+    {
+        "builds": List["BuildTypeDef"],
+        "buildsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+BatchGetProjectsOutputTypeDef = TypedDict(
+    "BatchGetProjectsOutputTypeDef",
+    {
+        "projects": List["ProjectTypeDef"],
+        "projectsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+BatchGetReportGroupsOutputTypeDef = TypedDict(
+    "BatchGetReportGroupsOutputTypeDef",
+    {
+        "reportGroups": List["ReportGroupTypeDef"],
+        "reportGroupsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+BatchGetReportsOutputTypeDef = TypedDict(
+    "BatchGetReportsOutputTypeDef",
+    {
+        "reports": List["ReportTypeDef"],
+        "reportsNotFound": List[str],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+BuildBatchFilterTypeDef = TypedDict("BuildBatchFilterTypeDef", {"status": StatusType}, total=False)
+
+CreateProjectOutputTypeDef = TypedDict(
+    "CreateProjectOutputTypeDef",
+    {"project": "ProjectTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+CreateReportGroupOutputTypeDef = TypedDict(
+    "CreateReportGroupOutputTypeDef",
+    {"reportGroup": "ReportGroupTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+CreateWebhookOutputTypeDef = TypedDict(
+    "CreateWebhookOutputTypeDef",
+    {"webhook": "WebhookTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+DeleteBuildBatchOutputTypeDef = TypedDict(
+    "DeleteBuildBatchOutputTypeDef",
+    {
+        "statusCode": str,
+        "buildsDeleted": List[str],
+        "buildsNotDeleted": List["BuildNotDeletedTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+DeleteSourceCredentialsOutputTypeDef = TypedDict(
+    "DeleteSourceCredentialsOutputTypeDef",
+    {"arn": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+DescribeCodeCoveragesOutputTypeDef = TypedDict(
+    "DescribeCodeCoveragesOutputTypeDef",
+    {
+        "nextToken": str,
+        "codeCoverages": List["CodeCoverageTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+DescribeTestCasesOutputTypeDef = TypedDict(
+    "DescribeTestCasesOutputTypeDef",
+    {
+        "nextToken": str,
+        "testCases": List["TestCaseTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+GetReportGroupTrendOutputTypeDef = TypedDict(
+    "GetReportGroupTrendOutputTypeDef",
+    {
+        "stats": "ReportGroupTrendStatsTypeDef",
+        "rawData": List["ReportWithRawDataTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+GetResourcePolicyOutputTypeDef = TypedDict(
+    "GetResourcePolicyOutputTypeDef",
+    {"policy": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ImportSourceCredentialsOutputTypeDef = TypedDict(
+    "ImportSourceCredentialsOutputTypeDef",
+    {"arn": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListBuildBatchesForProjectOutputTypeDef = TypedDict(
+    "ListBuildBatchesForProjectOutputTypeDef",
+    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListBuildBatchesOutputTypeDef = TypedDict(
+    "ListBuildBatchesOutputTypeDef",
+    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListBuildsForProjectOutputTypeDef = TypedDict(
+    "ListBuildsForProjectOutputTypeDef",
+    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListBuildsOutputTypeDef = TypedDict(
+    "ListBuildsOutputTypeDef",
+    {"ids": List[str], "nextToken": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListCuratedEnvironmentImagesOutputTypeDef = TypedDict(
+    "ListCuratedEnvironmentImagesOutputTypeDef",
+    {"platforms": List["EnvironmentPlatformTypeDef"], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListProjectsOutputTypeDef = TypedDict(
+    "ListProjectsOutputTypeDef",
+    {"nextToken": str, "projects": List[str], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListReportGroupsOutputTypeDef = TypedDict(
+    "ListReportGroupsOutputTypeDef",
+    {"nextToken": str, "reportGroups": List[str], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListReportsForReportGroupOutputTypeDef = TypedDict(
+    "ListReportsForReportGroupOutputTypeDef",
+    {"nextToken": str, "reports": List[str], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListReportsOutputTypeDef = TypedDict(
+    "ListReportsOutputTypeDef",
+    {"nextToken": str, "reports": List[str], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListSharedProjectsOutputTypeDef = TypedDict(
+    "ListSharedProjectsOutputTypeDef",
+    {"nextToken": str, "projects": List[str], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListSharedReportGroupsOutputTypeDef = TypedDict(
+    "ListSharedReportGroupsOutputTypeDef",
+    {"nextToken": str, "reportGroups": List[str], "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ListSourceCredentialsOutputTypeDef = TypedDict(
+    "ListSourceCredentialsOutputTypeDef",
+    {
+        "sourceCredentialsInfos": List["SourceCredentialsInfoTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
+)
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+)
+
+PutResourcePolicyOutputTypeDef = TypedDict(
+    "PutResourcePolicyOutputTypeDef",
+    {"resourceArn": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+ReportFilterTypeDef = TypedDict("ReportFilterTypeDef", {"status": ReportStatusType}, total=False)
+
+RetryBuildBatchOutputTypeDef = TypedDict(
+    "RetryBuildBatchOutputTypeDef",
+    {"buildBatch": "BuildBatchTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+RetryBuildOutputTypeDef = TypedDict(
+    "RetryBuildOutputTypeDef",
+    {"build": "BuildTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+StartBuildBatchOutputTypeDef = TypedDict(
+    "StartBuildBatchOutputTypeDef",
+    {"buildBatch": "BuildBatchTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+StartBuildOutputTypeDef = TypedDict(
+    "StartBuildOutputTypeDef",
+    {"build": "BuildTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+StopBuildBatchOutputTypeDef = TypedDict(
+    "StopBuildBatchOutputTypeDef",
+    {"buildBatch": "BuildBatchTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+StopBuildOutputTypeDef = TypedDict(
+    "StopBuildOutputTypeDef",
+    {"build": "BuildTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+TestCaseFilterTypeDef = TypedDict(
+    "TestCaseFilterTypeDef", {"status": str, "keyword": str}, total=False
+)
+
+UpdateProjectOutputTypeDef = TypedDict(
+    "UpdateProjectOutputTypeDef",
+    {"project": "ProjectTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+UpdateReportGroupOutputTypeDef = TypedDict(
+    "UpdateReportGroupOutputTypeDef",
+    {"reportGroup": "ReportGroupTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
+
+UpdateWebhookOutputTypeDef = TypedDict(
+    "UpdateWebhookOutputTypeDef",
+    {"webhook": "WebhookTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
+)
